@@ -6,7 +6,7 @@
 #________________________________________________________________________
 
 package Math::Algebra::Symbols;
-$VERSION = 1.13;
+$VERSION = 1.14;
 
 use Math::Algebra::SymbolsSum;
 use Math::Algebra::SymbolsTerm;
@@ -210,6 +210,7 @@ sub multiply3 {$_[0]->multiply3 ($_[1],$_[2])}
 sub divide3   {$_[0]->divide3   ($_[1],$_[2])}
 sub power3    {$_[0]->power3    ($_[1],$_[2])}
 sub equals3   {$_[0]->equals3   ($_[1],$_[2])}
+sub nequal3   {$_[0]->nequal3   ($_[1],$_[2])}
 sub tequals3  {$_[0]->tequals3  ($_[1],$_[2])}
 sub print3    {$_[0]->print3    ($_[1],$_[2])}
 sub sqrt3     {$_[0]->sqrt3     ($_[1],$_[2])}
@@ -229,6 +230,9 @@ sub conjugate3{$_[0]->conjugate3($_[1],$_[2])}
 #________________________________________________________________________
 
 1;
+
+__DATA__
+
 #______________________________________________________________________
 # User guide.
 #______________________________________________________________________
@@ -239,7 +243,7 @@ Math::Algebra::Symbols - Symbolic Algebra using Perl
 
 =head1 SYNOPSIS
 
- use Math::Algebra::Symbols hyper=>1;
+ use Maths::Algebra::Symbols hyper=>1;
 
  ($n, $x, $y) = symbols(qw(n x y));
 
@@ -268,7 +272,7 @@ L</Methods>.  For examples, see: L</Examples>.
 
 Symbols are created with the exported B<symbols()> constructor routine:
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  my ($x, $y, $i, $o, $pi) = symbols(qw(x y i 1 pi));
 
@@ -284,7 +288,7 @@ The special symbol B<i> is recognized as the square root of B<-1>.
 The special symbol B<pi> is recognized as the smallest positive real
 that satisfies:
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($i, $pi) = symbols(qw(i pi));
 
@@ -297,7 +301,7 @@ that satisfies:
 If you wish to use a different name for the constructor routine, say
 B<S>:
 
- use Math::Algebra::Symbols symbols=>'S';
+ use Maths::Algebra::Symbols symbols=>'S';
 
  my ($x, $y, $i, $o) = S(qw(x y i 1));
 
@@ -307,9 +311,9 @@ B<S>:
 
 =head3 Constructing Expressions with Big Integers
 
-If you wish to use symbols constructed with big integers from L<Math::BigInt>:
+If you wish to use Maths::Algebra::Symbols constructed with big integers from L<Math::BigInt>:
 
- use Math::Algebra::Symbols BigInt=>1;
+ use Maths::Algebra::Symbols BigInt=>1;
 
  my $z = symbols('1234567890987654321/1234567890987654321');
 
@@ -326,7 +330,7 @@ L</Symbols> can be combined with L</Operators> to create symbolic expressions:
 
 =head4 Arithmetic Operators: B<+> B<-> B<*> B</> B<**> 
             
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($x, $y) = symbols(qw(x y));
 
@@ -341,7 +345,7 @@ work courtesy of Perl Auto-Magical Operator Generation.
 
 =head4 Square root Operator: B<sqrt>       
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  $x = symbols(qw(x));
 
@@ -353,7 +357,7 @@ work courtesy of Perl Auto-Magical Operator Generation.
 
 =head4 Exponential Operator: B<exp>       
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  $x = symbols(qw(x));
 
@@ -365,7 +369,7 @@ work courtesy of Perl Auto-Magical Operator Generation.
 
 =head4 Logarithm Operator: B<log>       
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  $x = symbols(qw(x));
 
@@ -377,7 +381,7 @@ work courtesy of Perl Auto-Magical Operator Generation.
 
 =head4 Sine and Cosine Operators: B<sin> and B<cos>       
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  $x = symbols(qw(x));
 
@@ -389,9 +393,9 @@ work courtesy of Perl Auto-Magical Operator Generation.
 
 =head3 Relational operators                                   
 
-=head4 Relational operator: B<==> 
+=head4 Relational operators: B<==>, B<!=> 
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($x, $y) = symbols(qw(x y));
 
@@ -402,11 +406,12 @@ work courtesy of Perl Auto-Magical Operator Generation.
  # 1
 
 The relational equality operator B<==> compares two symbolic expressions
-and returns TRUE(1) or FALSE(0) accordingly.
+and returns TRUE(1) or FALSE(0) accordingly. B<!=> produces the opposite
+result.
 
 =head4 Relational operator: B<eq> 
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($x, $v, $t) = symbols(qw(x v t));
 
@@ -424,7 +429,7 @@ function will be used to simplify and rearrange the equation.
 
 =head4 Complex operators: the B<dot> operator: B<^>       
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($a, $b, $i) = symbols(qw(a b i));
 
@@ -442,7 +447,7 @@ to which the vector dot product is applied.
 
 =head4 Complex operators: the B<cross> operator: B<x>       
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($x, $i) = symbols(qw(x i));
 
@@ -462,7 +467,7 @@ the expression correctly.
 
 =head4 Complex operators: the B<conjugate> operator: B<~>       
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($x, $y, $i) = symbols(qw(x y i));
 
@@ -476,7 +481,7 @@ The B<~> operator returns the complex conjugate of its right hand side.
 
 =head4 Complex operators: the B<modulus> operator: B<abs>       
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($x, $i) = symbols(qw(x i));
 
@@ -490,7 +495,7 @@ The B<abs> operator returns the modulus (length) of its right hand side.
 
 =head4 Complex operators: the B<unit> operator: B<!>       
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  $i = symbols(qw(i));
 
@@ -519,7 +524,7 @@ the user's namespace as described in L</EXPORT>.
 
 =head4 Trigonometric functions
 
- use Math::Algebra::Symbols trig=>1;
+ use Maths::Algebra::Symbols trig=>1;
 
  ($x, $y) = symbols(qw(x y));
 
@@ -535,7 +540,7 @@ as methods.
 
 =head4 Hyperbolic functions
 
- use Math::Algebra::Symbols hyper=>1;
+ use Maths::Algebra::Symbols hyper=>1;
 
  ($x, $y) = symbols(qw(x y));
 
@@ -553,7 +558,7 @@ as methods.
 
 =head4 Complex functions: B<re> and B<im>       
 
- use Math::Algebra::Symbols complex=>1;
+ use Maths::Algebra::Symbols complex=>1;
 
  ($x, $i) = symbols(qw(x i));
 
@@ -570,7 +575,7 @@ variables represent real numbers.
 
 =head4 Complex functions: B<dot> and B<cross>       
 
- use Math::Algebra::Symbols complex=>1;
+ use Maths::Algebra::Symbols complex=>1;
 
  $i = symbols(qw(i));
 
@@ -586,7 +591,7 @@ exports to the caller's name space, or as methods.
 
 =head4 Complex functions: B<conjugate>, B<modulus> and B<unit>       
 
- use Math::Algebra::Symbols complex=>1;
+ use Maths::Algebra::Symbols complex=>1;
 
  $i = symbols(qw(i));
 
@@ -614,7 +619,7 @@ overloading.
 
 =head4 Simplifying equations: B<sub()>
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
  
  ($x, $y) = symbols(qw(x y));
  
@@ -645,7 +650,7 @@ or similar will produce approximate results.
 
 =head4 Solving equations: B<solve()>
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($x, $v, $t) = symbols(qw(x v t));
 
@@ -668,7 +673,7 @@ removes these variables, an error is reported via B<die()> if it does not.
 
 =head4 Differentiation: B<d()>
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($x, $i) = S(qw(x i));
 
@@ -694,7 +699,7 @@ used in honor of Newton, Leibnitz, Cauchy.
 
 =head3 Example Expressions
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  ($a, $b, $x, $y, $i) = symbols(qw(a b x y i));
 
@@ -730,7 +735,7 @@ used in honor of Newton, Leibnitz, Cauchy.
 
 =head3 Example of Equation Solving: the focii of a hyperbola:
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
  ($a, $b, $x, $y, $i, $o) = symbols(qw(a b x y i 1));
 
  print
@@ -753,7 +758,7 @@ is a hyperbola.
 
 =head3 Further Examples
 
- use Math::Algebra::Symbols;
+ use Maths::Algebra::Symbols;
 
  $x = symbols(qw(x));
 
@@ -823,9 +828,84 @@ B<modulus>, B<re>, B<unit> to the caller's namespace.
 
 =back
 
+=head1 PACKAGES
+
+The Symbols packages manipulate a sum of products representation of an
+algebraic equation. The B<Symbols> package is the user interface to the
+functionality supplied by the B<SymbolsSum> and B<SymbolsTerm> packages.
+
+=head2 Math::Algebra::SymbolsTerm
+
+B<SymbolsTerm> represents a product term. A product term consists of the
+number B<1>, optionally multiplied by:
+
+=over
+
+=item Variables
+
+any number of variables raised to integer powers,
+
+=item Coefficient
+
+An integer coefficient optionally divided by a positive integer divisor,
+both represented as BigInts if necessary. 
+
+=item Sqrt
+
+The sqrt of of any symbolic expression representable by the B<Symbols>
+package, including minus one: represented as B<i>.
+
+=item Reciprocal
+
+The multiplicative inverse of any symbolic expression representable by
+the B<Symbols> package: i.e. a B<SymbolsTerm> may be divided by any
+symbolic expression representable by the B<Symbols> package.
+
+=item Exp
+
+The number B<e> raised to the power of any symbolic expression
+representable by the B<Symbols> package.
+
+=item Log
+
+The logarithm to base B<e> of any symbolic expression representable by
+the B<Symbols> package.
+
+=back
+
+Thus B<SymbolsTerm> can represent expressions like:
+
+  2/3*x**2*y**-3*exp(i*pi)*sqrt(z**3) / x
+
+but not:
+
+  x + y
+
+for which package B<SymbolsSum> is required. 
+
+
+=head2 Math::Algebra::SymbolsSum
+
+B<SymbolsSum> represents a sum of product terms supplied by
+B<SymbolsTerm> and thus behaves as a polynomial. Operations such as
+equation solving and differentiation are applied at this level.
+
+The main benefit of programming B<SymbolsTerm> and B<SymbolsSum> as two
+separate but related packages is Object Oriented Polymorphism. I.e. both
+packages need to multiply items together: each package has its own B<multiply> method,
+with Perl method lookup selecting the appropriate one as required. 
+
+=head2 Math::Algebra::Symbols
+
+Packaging the user functionality separately in package B<Symbols> allows
+the internal functions to be conveniently hidden from user scripts.
+
+
 =head1 AUTHOR
 
 Philip R Brenan at B<philiprbrenan@yahoo.com>
 
 =cut
 
+
+
